Package: tempdisagg
Version: 1.1.1
Date: 2023-08-08
Title: Methods for Temporal Disaggregation and Interpolation of Time
        Series
Authors@R: c(
    person("Christoph", "Sax", email = "christoph.sax@gmail.com", role = c("aut", "cre"), comment = c(ORCID = "0000-0002-7192-7044")),
    person("Peter", "Steiner", role = c("aut")),
    person("Tommaso", "Di Fonzo", role = "ctb"))
URL: https://journal.r-project.org/archive/2013-2/sax-steiner.pdf
BugReports: https://github.com/christophsax/tempdisagg
Suggests: tsbox, testthat, knitr, rmarkdown, covr
Description: Temporal disaggregation methods are used to disaggregate and
    interpolate a low frequency time series to a higher frequency series, where
    either the sum, the mean, the first or the last value of the resulting
    high frequency series is consistent with the low frequency series. Temporal
    disaggregation can be performed with or without one or more high frequency
    indicator series. Contains the methods of Chow-Lin, Santos-Silva-Cardoso,
    Fernandez, Litterman, Denton and Denton-Cholette, summarized in Sax and
    Steiner (2013) <doi:10.32614/RJ-2013-028>. Supports most R time series
    classes.
License: GPL-3
LazyLoad: yes
RoxygenNote: 7.2.3
Encoding: UTF-8
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2023-08-08 15:07:00 UTC; christophsax
Author: Christoph Sax [aut, cre] (<https://orcid.org/0000-0002-7192-7044>),
  Peter Steiner [aut],
  Tommaso Di Fonzo [ctb]
Maintainer: Christoph Sax <christoph.sax@gmail.com>
Repository: CRAN
Date/Publication: 2023-08-08 15:20:02 UTC
Built: R 4.4.0; ; 2024-05-06 21:20:29 UTC; unix
