# Generated by roxygen2: do not edit by hand

S3method(plot,td)
S3method(predict,td)
S3method(print,summary.td)
S3method(print,td)
S3method(summary,td)
S3method(ta,ts)
export(ta)
export(td)
import(graphics)
import(stats)
import(utils)
